reset method
Clears the log history, restoring the logger to its initial state.
Implementation
@override
void reset() {
_logHistory.clear();
}
Clears the log history, restoring the logger to its initial state.
@override
void reset() {
_logHistory.clear();
}