CountedClonerBuilder class final

Builder for CountedCloner

Implemented types

Constructors

CountedClonerBuilder()
Allows configuration of CountedCloner options before instantiation. Example:

Properties

doTypedClone bool
Whether to perform typed cloning.
no getteroverride
hashCode int
The hash code for this object.
no setterinherited
nestLimit int
Maximum allowed nesting depth for recursive cloning
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeLimit int
Maximum number of values allowed to be cloned
getter/setter pair

Methods

build() CountedCloner
Creates a new CountedCloner instance with the current builder settings.
override
deserialize(covariant String data) CountedCloner
Restores a CountedCloner from a string produced by serialize.
override
instance() IClonerBuilding
Returns a new IClonerBuilding instance (a simple constructor alternative).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize({CountedCloner? source, bool short = false}) String
Serializes the current builder configuration or a CountedCloner instance.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited