IBuildable class abstract interface

Interface for extracting a builder from an instance, enabling constructorless builder access.

Suggested for ICloning implementations to allow obtaining a configured IClonerBuilding without direct constructors.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

builder() IClonerBuilding
Returns a builder for this instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited