MClonerLogging mixin

Mixin that provides logging for cloning operations using BaseCloneLogger.

When applied to a class implementing ICloning, this mixin logs each clone operation, including the type and size of the data being cloned. Logging output can be enabled or disabled via doPrintOnLog, and the log history can be accessed using showLogs.

See also:

Example:

base class MyCloner implements ICloning { /* custom Cloner implementation */ }
final class MyLoggedCloner extends MyCloner with MClonerLogging { /* can be empty */ }
Superclass constraints
Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cloneList<E>(List<E> source) List
Logs and clones a list.
override
cloneMap<K, V>(Map<K, V> source) Map<K, dynamic>
Logs and clones a map with dynamic values.
override
cloneSet<E>(Set<E> source) Set
Logs and clones a set.
override
cloneValue(dynamic source) → dynamic
Logs and clones a value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Delegates to logger BaseCloneLogger.reset.
override
showLogs() Iterable<String>
Delegates to logger BaseCloneLogger.showLogs.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited