PureCloner class base

Performs deep cloning for common Dart collections and objects. Does not preserve type arguments or underlying collection implementations.

Supports cloning of List, Set, Map, and objects implementing ICloneable. Primitives are returned as-is.

Implemented types

Constructors

PureCloner()
pure. const.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cloneList<E>(List<E> source) List
Returns a dynamic deep clone of the given list.
override
cloneMap<K, V>(Map<K, V> source) Map<K, dynamic>
Returns a dynamic deep clone of the given map.
override
cloneSet<E>(Set<E> source) Set
Returns a dynamic deep clone of the given set.
override
cloneValue(dynamic source) → dynamic
Clones source recursively. Supports ICloneable, List, Set, Map, and returns primitives as-is.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited