PureClonerBuilder class final
Placeholder builder to enable PureCloner usage inside Cloner.
- Implemented types
Constructors
- PureClonerBuilder()
-
Creates a new PureClonerBuilder.
const
Properties
- doTypedClone ← bool
-
Throws UnsupportedError as PureCloner does not support strict typed cloning.
no getteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → ICloning -
Builds and returns a PureCloner.
override
-
instance(
) → PureClonerBuilder -
Returns a new PureClonerBuilder instance.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited