IMapCloning class abstract interface

Interface for cloning map structures.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cloneMap<K, V>(Map<K, V> source) Map<K, dynamic>
Clones a map, producing a new map with keys and dynamic values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited