AdaptiveCloner class base
Dispatches cloning operations to appropriate delegates based on configuration.
- Implemented types
Properties
- doTypedClone → bool
-
Enables typed cloning for collections when true.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAOT → bool
-
Indicates if the runtime is ahead-of-time compiled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
builder(
{bool isAOT = AdaptiveClonerBuilder.DART_IS_AOT}) → IClonerBuilding -
Returns a builder for constructing an AdaptiveCloner instance.
override
-
cloneList<
E> (List< E> source) → List -
Clones a list, using typed or dynamic delegate based on doTypedClone.
override
-
cloneMap<
K, V> (Map< K, V> source) → Map<K, dynamic> -
Clones a map, using typed or dynamic delegate based on doTypedClone.
override
-
cloneMapTyped<
K, V> (Map< K, V> source) → Map<K, V> -
Clones a map, using typed delegate.
override
-
cloneSet<
E> (Set< E> source) → Set -
Clones a set, using typed or dynamic delegate based on doTypedClone.
override
-
cloneValue(
dynamic source) → dynamic -
Clones a single value using the value delegate.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited