Combines logging, log retrieval, and print control.
- Inheritance
- Implemented types
-
- IShowLogging<
T> - IPrintLogging<
T>
- IShowLogging<
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- printOnLog → bool
-
Indicates if log messages are printed when logged.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
doPrintOnLog(
bool value) → void -
Enables or disables printing of log messages.
inherited
-
log(
T message) → void -
Logs a message.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printLog(
T message) → void -
Prints a log message.
inherited
-
showLogs(
) → Iterable< T> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited