Controls printing of log messages.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- printOnLog → bool
-
Indicates if log messages are printed when logged.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
doPrintOnLog(
bool value) → void - Enables or disables printing of log messages.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printLog(
T message) → void - Prints a log message.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited