MBaseClonerLogging mixin base
Mixin that adds logging capabilities to BaseCloner using BaseCloneLogger. Provides access to log history via showLogs and allows resetting logs with reset.
See also:
- ILogging for the logging interface.
- BaseCloneLogger for the logger implementation.
Example:
final class MyLoggedCloner with MBaseClonerLogging {
MyLoggedCloner(super.doTypedClone);
}
- Superclass constraints
- Implemented types
Properties
- doTypedClone → bool
-
Enables typed cloning for collections when true.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
builder(
) → IClonerBuilding -
Returns a builder for constructing a BaseCloner instance.
inherited
-
cloneList<
E> (List< E> source) → List<E> -
Logs and clones a list.
override
-
cloneMap<
K, V> (Map< K, V> source) → Map<K, dynamic> -
Logs and clones a map with dynamic values.
override
-
cloneMapTyped<
K, V> (Map< K, V> source) → Map<K, V> -
Logs and clones a map with typed values.
override
-
cloneSet<
E> (Set< E> source) → Set<E> -
Logs and clones a set.
override
-
cloneValue(
dynamic source) → dynamic -
Logs and clones a value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
Delegates to logger BaseCloneLogger.reset.
override
-
showLogs(
) → Iterable< String> -
Delegates to logger BaseCloneLogger.showLogs.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited