MClonerLogging mixin
A mixin that adds logging capabilities to cloning operations.
When applied to a class that implements ICloning, this mixin provides logging for each clone operation, including the type and size of the data being cloned. Logging can be enabled or disabled via enablePrinting, and the log history can be accessed using showLog.
Example usage:
final class MyCloner extends BaseCloner with MClonerLogging { ... }
- Superclass constraints
Properties
- enablePrinting ↔ bool
-
If true, logs will be printed for each clone operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cloneList<
E> (List< E> source) → List<E> -
Logs and clones a list.
override
-
cloneMap<
K, V> (Map< K, V> source) → Map<K, dynamic> -
Logs and clones a map with dynamic values.
override
-
cloneMapTyped<
K, V> (Map< K, V> source) → Map<K, V> -
Logs and clones a typed map.
override
-
cloneSet<
E> (Set< E> source) → Set<E> -
Logs and clones a set.
override
-
cloneValue(
dynamic source) → dynamic -
Logs and clones a value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showLog(
) → Iterable< String> - Returns an iterable of log messages, LIFO (most recent first).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited